@@ -179,6 +179,7 @@ in contrast to the other create_type() functions."""
             return self.target_giname
         elif self.target_foreign:
             return self.target_foreign
+        return '<undefined>'
 
     def __repr__(self):
         if self.target_fundamental:
@@ -460,6 +461,7 @@ class Namespace(object):
         self.shared_libraries = []   # str
         self.c_includes = []         # str
         self.exported_packages = []  # str
+        self.doc_format = "unknown"
 
     def type_from_name(self, name, ctype=None):
         """Backwards compatibility method for older .gir files, which
