@@ -782,6 +782,8 @@ class DocFormatterPython(DocFormatterIntrospectableBase):
             "gulong": "int",
             "gint64": "int",
             "guint64": "int",
+            "time_t": "int",
+            "off_t": "int",
             "gfloat": "float",
             "gdouble": "float",
             "gchararray": "str",
@@ -923,6 +925,8 @@ class DocFormatterGjs(DocFormatterIntrospectableBase):
             "gulong": "Number(gulong)",
             "gint64": "Number(gint64)",
             "guint64": "Number(guint64)",
+            "time_t": "Number(time_t)",
+            "off_t": "Number(off_t)",
             "long double": "Number(long double)",
             "long long": "Number(long long)",
             "unsigned long long": "Number(unsigned long long)"}
@@ -945,7 +949,7 @@ class DocFormatterGjs(DocFormatterIntrospectableBase):
             if giname == 'Gdk.Atom':
                 return 'String'
             if giname in ('GLib.ByteArray', 'GLib.Bytes'):
-                return 'ByteArray'
+                return 'Uint8Array'
             if giname == 'GObject.Value':
                 return 'Any'
             if giname == 'GObject.Closure':
@@ -1149,7 +1153,7 @@ class DevDocsFormatterGjs(DocFormatterGjs):
                     "gchar", "guchar", "gshort", "gint", "guint", "gfloat",
                     "gdouble", "gsize", "gssize", "gintptr", "guintptr",
                     "glong", "gulong", "gint64", "guint64", "long double",
-                    "long long", "unsigned long long"]:
+                    "long long", "unsigned long long", "time_t", "off_t"]:
             return "Number"  # gsize and up cannot fully be represented in GJS
         if name in ["none", "gpointer"]:
             return "void"
@@ -1274,6 +1278,12 @@ class DevDocsFormatterGjs(DocFormatterGjs):
     def format_in_parameters(self, node):
         return ', '.join(p.argname for p in self.get_in_parameters(node))
 
+    def format_signal_parameters(self, node):
+        emitter = self.to_lower_camel_case(node.parent.name)
+        in_params = self.format_in_parameters(node)
+
+        return '%s, %s' % (emitter, in_params) if in_params else emitter
+
 
 LANGUAGES = {
     "devdocs": {
